from enum import Enum


class MessageType(Enum):
    CONNECTION_REQUEST = "CONNECTION_REQUEST"
    CONNECTION_RESPONSE = "CONNECTION_RESPONSE"
    ALIVE_REQUEST = "ALIVE_REQUEST"
    ALIVE_RESPONSE = "ALIVE_RESPONSE"
    NEW_NOTIFICATION = "NEW_NOTIFICATION"
    PRESENCE = "PRESENCE"
