from enum import StrEnum


class NotificationSubType(StrEnum):
    # INVITE_EXTERNAL_FRIEND
    MENTION = "REV_MENTION_MSG"
    NOTE_COMMENT_MENTION = "REV_MENTION_NOTE_COMMENT"
    INVITE_LINE = "REV_ADD_FRIEND_LINE"
    INVITE_WORKSAT = "REV_ADD_FRIEND_WORKSAT"
    # NOTE_POST
    NOTE_WRITE = "REV_NOTE_WRITE"
    NOTE_NOTICE = "REV_NOTE_NOTICE"
    NOTE_SHARE = "REV_NOTE_SHARE"
    # GROUP_CALL_AND_SCREEN_SHARE
    GROUP_VOICE_CALL_INVITE = "REV_GROUP_CALL_INVITE"
    GROUP_VOICE_CALL_START = "REV_GROUP_CALL_START"
    GROUP_SCREEN_SHARE_INVITE = "REV_GROUP_RD_INVITE"
    GROUP_SCREEN_SHARE_START = "REV_GROUP_RD_START"
    GROUP_VIDEO_CALL_INVITE = "REV_GROUP_VCALL_INVITE"
    GROUP_VIDEO_CALL_START = "REV_GROUP_VCALL_START"
    GROUP_VOICE_CALL_AND_SCREEN_SHARE_INVITE = "REV_GROUP_CALL_RD_INVITE"
    GROUP_VIDEO_CALL_AND_SCREEN_SHARE_INVITE = "REV_GROUP_VCALL_RD_INVITE"
