from enum import IntEnum


class ServiceSubType(IntEnum):
    ADMIN = 1
    BOARD = 2
    CALENDAR = 3
    CONTACT = 4
    TASK = 5
    FORM = 6
    DRIVE = 7
    APPROVAL = 8
    RESERVATION = 9
    MYWORK = 10
    CLOVANOTE = 11
    CSTALK = 12
